@@ -22,18 +22,19 @@
 #include <QtDeclarative>
 #include "settings.h"
 #include "dataprovider.h"
-#include "quranview.h"
+#include "quranviewmodel.h"
 #include "bookmarks.h"
 #include "numberformatter.h"
 #include "logoprovider.h"
 #include "themeimageprovider.h"
-#include "legal.h"
+#include "aboutdata.h"
 #include <QDir>
 #include "windowcontroller.h"
 #include "translations.h"
 #include "translation.h"
 #include "downloader.h"
 #include "fsmonitor.h"
+#include "label.h"
 
 #ifndef Q_WS_MAEMO_5
 #include <MDeclarativeCache>
@@ -78,18 +79,18 @@ M_DECL_EXPORT int main(int argc, char *argv[]) {
 
   NumberFormatter formatter(&settings);
 
-  Legal legal;
+  AboutData about;
 
   qmlRegisterType<DataProvider>();
   qmlRegisterType<Settings>();
   qmlRegisterType<Bookmarks>();
   qmlRegisterType<NumberFormatter>();
-  qmlRegisterType<Legal>();
+  qmlRegisterType<AboutData>();
   qmlRegisterType<Translations>();
   qmlRegisterType<FSMonitor>();
   qmlRegisterType<Translation>("Translations", 1, 0, "Translation");
-  qmlRegisterType<QuranView>("Quran", 1, 0, "QuranView");
-
+  qmlRegisterType<QuranViewModel>("QuranViewModel", 1, 0, "QuranViewModel");
+  qmlRegisterType<Label>("Label2", 1, 0, "Label2");
 
 #ifndef Q_WS_MAEMO_5
   QDeclarativeView *view = MDeclarativeCache::qDeclarativeView();
@@ -102,17 +103,20 @@ M_DECL_EXPORT int main(int argc, char *argv[]) {
 
   QObject::connect(view->engine(), SIGNAL(quit()), app, SLOT(quit()));
 
+  ThemeImageProvider *theme = new ThemeImageProvider(DATA_DIR "/themes/");
+
   view->engine()->addImageProvider("quran", new LogoProvider);
-  view->engine()->addImageProvider("theme", new ThemeImageProvider);
+  view->engine()->addImageProvider("theme", theme);
 
   view->rootContext()->setContextProperty("_settings", &settings);
   view->rootContext()->setContextProperty("_data", &data);
   view->rootContext()->setContextProperty("_bookmarks", &bookmarks);
   view->rootContext()->setContextProperty("_formatter", &formatter);
-  view->rootContext()->setContextProperty("_legal", &legal);
+  view->rootContext()->setContextProperty("_about", &about);
   view->rootContext()->setContextProperty("_translations", &translations);
   view->rootContext()->setContextProperty("_downloader", &downloader);
   view->rootContext()->setContextProperty("_fsmon", &monitor);
+  view->rootContext()->setContextProperty("_theme", theme);
 
   if (dev) {
     view->setSource(QUrl::fromLocalFile(QDir::currentPath() + "/main.qml"));
